package com.muyu.enterpise.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.domain.SysCar;
import com.muyu.domain.req.SysCarReq;
import com.muyu.domain.resp.SysCarResp;
import com.muyu.enterpise.mapper.SysCarMapper;
import com.muyu.enterpise.service.SysCarService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.ArrayList;
import java.util.List;

/**
 * 车辆基础信息Service业务层处理
 * @author LiHD
 * @date 2024-09-18
 */
@Service
public class SysCarServiceImpl
        extends ServiceImpl<SysCarMapper, SysCar>
        implements SysCarService {

    @Autowired
    private SysCarMapper sysCarMapper;

    /**
     * 精确查询车辆基础信息
     *
     * @param id 车辆基础信息主键
     * @return 车辆基础信息
     */
    @Override
    public SysCar selectSysCarById(Long id) {
        LambdaQueryWrapper<SysCar> queryWrapper = new LambdaQueryWrapper<>();
        Assert.notNull(id, "id不可为空");
        queryWrapper.eq(SysCar::getId, id);


        return this.getOne(queryWrapper);
    }


    /**
     * 查询车辆基础信息列表
     *
     * @param sysCarReq 车辆基础信息
     * @return 车辆基础信息
     */
    @Override
    public List<SysCarResp> selectSysCarList(SysCarReq sysCarReq) {
        LambdaQueryWrapper<SysCar> queryWrapper = new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(sysCarReq.getCarVin())) {
            queryWrapper.eq(SysCar::getCarVin,sysCarReq.getCarVin());
        }
        if (StringUtils.isNotEmpty(sysCarReq.getCarPlate())) {
            queryWrapper.like(SysCar::getCarPlate, sysCarReq.getCarPlate());
        }
        if (StringUtils.isNotEmpty(sysCarReq.getCarBrand())) {
            queryWrapper.eq(SysCar::getCarBrand, sysCarReq.getCarBrand());
        }
        if (StringUtils.isNotEmpty(sysCarReq.getCarModel())) {
            queryWrapper.eq(SysCar::getCarModel, sysCarReq.getCarModel());
        }
        if (null == sysCarReq.getCarType()) {
            queryWrapper.eq(SysCar::getCarType, sysCarReq.getCarType());
        }
        if (null == sysCarReq.getState()) {
            queryWrapper.eq(SysCar::getState, sysCarReq.getState());
        }
        List<SysCar> list = this.list(queryWrapper);
        return list.stream()
                .map(SysCarResp::reverseResp)
                .toList();
    }


    /**
    * 唯一 判断
    * @param sysCar 车辆基础信息
     * @return 车辆基础信息
    */
    @Override
    public Boolean checkIdUnique(SysCar sysCar) {
        LambdaQueryWrapper<SysCar> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(SysCar::getId, sysCar.getId());
        return this.count(queryWrapper) > 0;
    }

}
